@@ -227,7 +227,7 @@ class CharmstoreColumn(WidgetWrap):
 
     def update(self):
         opts = self.pile.options()
-
+        extra_widgets = []
         if self.metadata_controller.loaded():
             if len(self._recommended_widgets) == 0:
                 rec_dicts = [self.metadata_controller.get_charm_info(n)
@@ -262,7 +262,7 @@ class CharmstoreColumn(WidgetWrap):
                                     "and Popular Charms…")
             else:
                 self.title.set_text("")
-
+            extra_widgets = self._recommended_widgets
         else:
             if self.loading:
                 msg = "\nSearching for '{}'…\n".format(
@@ -284,7 +284,7 @@ class CharmstoreColumn(WidgetWrap):
                            "".format(bn, cn, self.current_search_string))
             self.title.set_text(msg)
 
-        self.pile.contents[1:] = bundle_widgets + charm_widgets
+        self.pile.contents[1:] = extra_widgets + bundle_widgets + charm_widgets
 
     def add_results(self, bundle_results, charm_results):
         self._bundle_results += bundle_results
@@ -298,12 +298,13 @@ class CharmstoreColumn(WidgetWrap):
         self._charm_results = self._charm_results[:10]
 
     def focus_prev_or_top(self):
-        if len(self.pile.contents) > 2:
-            if self.state == CharmstoreColumnUIState.RELATED and \
-               not self.loading:
-                self.pile.focus_position = 1
-            else:
-                self.pile.focus_position = 2
+        if len(self.pile.contents) < 2:
+            return
+        if self.state == CharmstoreColumnUIState.RELATED and self.loading \
+           and len(self.pile.contents) > 2:
+            self.pile.focus_position = 2
+        else:
+            self.pile.focus_position = 1
 
     def do_add_charm(self, charm_name, charm_dict):
         self.placement_view.do_add_charm(charm_name,
