@@ -15,6 +15,7 @@ from conjure.controllers.cloud import CloudController
 from conjure.controllers.newcloud import NewCloudController
 from conjure.controllers.jujucontroller import JujuControllerController
 from conjure.controllers.bootstrapwait import BootstrapWaitController
+from conjure.controllers.lxdsetup import LXDSetupController
 from conjure.log import setup_logging
 import json
 import sys
@@ -44,6 +45,8 @@ class ApplicationConfig:
         self.controllers = None
         # Current Juju model
         self.current_model = None
+        # Current controller
+        self.current_controller = None
         # Global session id
         self.session_id = os.getenv('CONJURE_TEST_SESSION_ID',
                                     str(uuid.uuid4()))
@@ -77,6 +80,7 @@ class Application:
             'welcome': WelcomeController(self.app),
             'clouds': CloudController(self.app),
             'newcloud': NewCloudController(self.app),
+            'lxdsetup': LXDSetupController(self.app),
             'bootstrapwait': BootstrapWaitController(self.app),
             'deploy': DeployController(self.app),
             'deploysummary': DeploySummaryController(self.app),
@@ -129,6 +133,12 @@ def parse_options(argv):
 def main():
     opts = parse_options(sys.argv[1:])
 
+    if os.geteuid() == 0:
+        print("")
+        print("This should _not_ be run as root or with sudo.")
+        print("")
+        sys.exit(1)
+
     try:
         docs_url = "https://jujucharms.com/docs/stable/getting-started"
         juju_version = Juju.version()
