@@ -1,8 +1,10 @@
 from conjure.ui.views.newcloud import NewCloudView
 from conjure.models.provider import Schema
 from conjure.utils import juju_path, pollinate
+from configobj import ConfigObj
 import os.path as path
 import yaml
+import petname
 
 
 class NewCloudController:
@@ -35,28 +37,41 @@ class NewCloudController:
         credentials: credentials to store for provider
         back: if true loads previous controller
         """
+        self.app.current_controller = petname.Name()
+
         if back:
-            return self.app.controllers['clouds'].render()
+            return self.app.controllers['welcome'].render()
 
         cred_path = path.join(juju_path(), 'credentials.yaml')
-        if path.isfile(cred_path):
+        if not path.isfile(cred_path):
+            existing_creds = {
+                    'credentials': {
+                        self.cloud: {
+                            self.app.current_controller: self._format_creds(
+                                credentials)
+                        }
+                    }
+                }
+
+        else:
             existing_creds = yaml.safe_load(open(cred_path))
 
             if self.cloud in existing_creds['credentials'].keys():
                 c = existing_creds['credentials'][self.cloud]
-                c['conjure'] = self._format_creds(
+                c[self.app.current_controller] = self._format_creds(
                     credentials)
-        else:
-            existing_creds = {
-                'credentials': {
-                    self.cloud: {'conjure': self._format_creds(credentials)}
+            else:
+                # Handle the case where path exists but an entry for the cloud
+                # has yet to be added.
+                existing_creds['credentials'][self.cloud] = {
+                    self.app.current_controller: self._format_creds(
+                        credentials)
                 }
-            }
+
         with open(cred_path, 'w') as cred_f:
             cred_f.write(yaml.safe_dump(existing_creds,
                                         default_flow_style=False))
 
-        # FIXME: Handle these cases better
         if self.cloud == 'maas':
             self.cloud = '{}/{}'.format(self.cloud,
                                         credentials['@maas-server'].value)
@@ -70,8 +85,23 @@ class NewCloudController:
         Arguments:
         cloud: The cloud to create credentials for
         """
-        # if cloud is LXD bypass all this
+
+        # LXD is a special case as we want to make sure a bridge
+        # is configured. If not we'll bring up a new view to allow
+        # a user to configure a LXD bridge with suggested network
+        # information.
         if cloud == 'lxd':
+            if path.isfile('/etc/default/lxd-bridge'):
+                cfg = ConfigObj('/etc/default/lxd-bridge')
+            else:
+                cfg = ConfigObj()
+
+            ready = cfg.get('LXD_IPV4_ADDR', None)
+            if not ready:
+                return self.app.controllers['lxdsetup'].render()
+
+            self.app.log.debug("Found an IPv4 address ({}), "
+                               "assuming LXD is configured.".format(ready))
             return self.app.controllers['jujucontroller'].render(
                 cloud='lxd', bootstrap=True)
 
