@@ -106,23 +106,34 @@ class Juju:
         cls.is_authenticated = True
 
     @classmethod
-    def bootstrap(cls, controller, cloud):
+    def bootstrap(cls, controller, cloud, series=None, log=None):
         """ Performs juju bootstrap
 
+        If not LXD pass along the newly defined credentials
+
         Arguments:
         controller: name of your controller
         cloud: name of local or public cloud to deploy to
+        series: define the bootstrap series defaults to xenial
+        log: application logger
         """
-        cmd = ("juju bootstrap {} {} --upload-tools ".format(
-            controller, cloud))
+        cmd = "juju bootstrap {} {} --upload-tools ".format(
+                  controller, cloud, series)
+        if series is not None:
+            cmd += "--bootstrap-series={} ".format(series)
+        if cloud != "lxd" and cloud != "localhost":
+            cmd += "--credential {}".format(controller)
+        if log:
+            log.debug("bootstrap cmd: {}".format(cmd))
         return shell(cmd)
 
     @classmethod
-    def bootstrap_async(cls, controller, cloud, exc_cb=None):
+    def bootstrap_async(cls, controller, cloud,
+                        series=None, log=None, exc_cb=None):
         """ Performs a bootstrap asynchronously
         """
         return async.submit(partial(cls.bootstrap, controller,
-                                    cloud), exc_cb)
+                                    cloud, series, log), exc_cb)
 
     @classmethod
     def log(cls, limit=1):
@@ -262,15 +273,24 @@ class Juju:
         return None
 
     @classmethod
-    def controller_info(cls):
+    def controller_info(cls, name=None):
         """ Returns information on current controller
+
+        Arguments:
+        name: if set shows info controller, otherwise displays current.
         """
-        sh = shell('juju show-controller --format yaml')
+        cmd = 'juju show-controller --format yaml'
+        if name is not None:
+            cmd += ' {}'.format(name)
+        sh = shell(cmd)
         if sh.code > 0:
             raise JujuNotFoundException(
                 "Unable to determine controller: {}".format(sh.errors()))
         out = yaml.safe_load("\n".join(sh.output()))
-        return out
+        try:
+            return next(iter(out.values()))
+        except:
+            return out
 
     @classmethod
     def controllers(cls):
